@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import os
-from typing import Sequence
+from collections.abc import Sequence
 
 from pre_commit.lang_base import Language
 from pre_commit.prefix import Prefix
