@@ -40,6 +40,7 @@ def run_opts(
         color=False,
         verbose=False,
         hook=None,
+        fail_fast=False,
         remote_branch='',
         local_branch='',
         from_ref='',
@@ -65,6 +66,7 @@ def run_opts(
         color=color,
         verbose=verbose,
         hook=hook,
+        fail_fast=fail_fast,
         remote_branch=remote_branch,
         local_branch=local_branch,
         from_ref=from_ref,
