@@ -1,10 +1,18 @@
 from __future__ import annotations
 
+import pytest
+
 from pre_commit.languages import docker_image
+from pre_commit.util import cmd_output_b
 from testing.language_helpers import run_language
 from testing.util import xfailif_windows
 
 
+@pytest.fixture(autouse=True, scope='module')
+def _ensure_image_available():
+    cmd_output_b('docker', 'run', '--rm', 'ubuntu:22.04', 'echo')
+
+
 @xfailif_windows  # pragma: win32 no cover
 def test_docker_image_hook_via_entrypoint(tmp_path):
     ret = run_language(
